/* This file performs analyses for the ballot secrecy experiment performed during the 
   2012 Wisconsin recall election.*/

set more off
*set matsize 500
clear
log using logs/02_wisconsin_secret_ballot_analysis.txt, text replace

use wi_ballot_secrecy.dta, clear

*define common set of control variables
local controls = "yearssincereg age_corrected d_miss_age female d_miss_gender hhinc_corrected d_miss_hhinc asian black latino mideastern nativeamer d_miss_race"



*balance tests (table A1)
*pre-2008 summary statistics
sum vs_12_update `controls' milwaukee if post08reg == 0
mkcorr vs_12_update `controls' milwaukee if post08reg == 0, log(tables/TableA00-wi_ballot_secrecy_summary_table.out) replace means nocorr lab mdec(3)
mkcorr vs_12_update `controls' milwaukee if treat == 0 & post08reg == 0, log(tables/TableA01-1-wi_ballot_secrecy_summary_table_control.out) replace means nocorr lab mdec(3)
mkcorr vs_12_update `controls' milwaukee if treat == 1 & post08reg == 0, log(tables/TableA01-2-wi_ballot_secrecy_summary_table_treatment.out) replace means nocorr lab mdec(3)
count if treat == 0 & post08reg == 0
count if treat == 1 & post08reg == 0

*regress treatment assignment on controls (table A2)
reg treat `controls' if post08reg == 0
outreg using tables/TableA02-wi_ballot_secrecy_balance_test_table.out, 3aster se bracket replace tdec(3)
*test `controls' /*same as F-test reported with OLS results*/



**pre-2008 registrant analysis
*2010 recall election (table 1)
reg vs_12_update treat if post08reg == 0, r
outreg using tables/Table01-wi_ballot_secrecy_pre08_recall_table.out, 3aster se bracket replace tdec(3)
xtreg vs_12_update treat if post08reg == 0, r fe i(township_id)
outreg using tables/Table01-wi_ballot_secrecy_pre08_recall_table.out, 3aster se bracket append tdec(3) addstat("R-squared Within", `e(r2_w)')

*create in-sample counts of number of individuals within fixed-effects units for robustness checks
bysort township_id: egen numobsFE = count(e(sample)) if e(sample)
sort township_id
tab numobsFE if township_id != township_id[_n - 1]

reg vs_12_update treat `controls' if post08reg == 0, r
outreg using tables/Table01-wi_ballot_secrecy_pre08_recall_table.out, 3aster se bracket append tdec(3)
xtreg vs_12_update treat `controls' if post08reg == 0, r fe i(township_id)
outreg using tables/Table01-wi_ballot_secrecy_pre08_recall_table.out, 3aster se bracket append tdec(3) addstat("R-squared Within", `e(r2_w)')



**full study population analysis
*2010 recall election (appendix)
reg vs_12_update treat, r
outreg using tables/TableS01-wi_ballot_secrecy_full_recall_table.out, 3aster se bracket replace tdec(3)
xtreg vs_12_update treat, r fe i(township_id)
outreg using tables/TableS01-wi_ballot_secrecy_full_recall_table.out, 3aster se bracket append tdec(3) addstat("R-squared Within", `e(r2_w)')
reg vs_12_update treat `controls', r
outreg using tables/TableS01-wi_ballot_secrecy_full_recall_table.out, 3aster se bracket append tdec(3)
xtreg vs_12_update treat `controls', r fe i(township_id)
outreg using tables/TableS01-wi_ballot_secrecy_full_recall_table.out, 3aster se bracket append tdec(3) addstat("R-squared Within", `e(r2_w)')

**pre-2008 registrant analysis
*2010 general election (table 2)
reg vg_12_update treat if post08reg == 0, r
outreg using tables/Table02-wi_ballot_secrecy_pre08_general_table.out, 3aster se bracket replace tdec(3)
xtreg vg_12_update treat if post08reg == 0, r fe i(township_id)
outreg using tables/Table02-wi_ballot_secrecy_pre08_general_table.out, 3aster se bracket append tdec(3) addstat("R-squared Within", `e(r2_w)')
reg vg_12_update treat `controls' if post08reg == 0, r
outreg using tables/Table02-wi_ballot_secrecy_pre08_general_table.out, 3aster se bracket append tdec(3)
xtreg vg_12_update treat `controls' if post08reg == 0, r fe i(township_id)
outreg using tables/Table02-wi_ballot_secrecy_pre08_general_table.out, 3aster se bracket append tdec(3) addstat("R-squared Within", `e(r2_w)')

**full study population analysis
*2010 general election (appendix)
reg vg_12_update treat, r
outreg using tables/TableS02-wi_ballot_secrecy_full_general_table.out, 3aster se bracket replace tdec(3)
xtreg vg_12_update treat, r fe i(township_id)
outreg using tables/TableS02-wi_ballot_secrecy_full_general_table.out, 3aster se bracket append tdec(3) addstat("R-squared Within", `e(r2_w)')
reg vg_12_update treat `controls', r
outreg using tables/TableS02-wi_ballot_secrecy_full_general_table.out, 3aster se bracket append tdec(3)
xtreg vg_12_update treat `controls', r fe i(township_id)
outreg using tables/TableS02-wi_ballot_secrecy_full_general_table.out, 3aster se bracket append tdec(3) addstat("R-squared Within", `e(r2_w)')

*logistic regression (appendix)
logit vs_12_update treat if post08reg == 0, r
outreg using tables/TableS03-wi_ballot_secrecy_recall_logit_table.out, 3aster se bracket replace tdec(3) addstat("Pseudo R-squared", `e(r2_p)', "Log-likelihood", `e(ll)')
logit vs_12_update treat `controls' if post08reg == 0, r
outreg using tables/TableS03-wi_ballot_secrecy_recall_logit_table.out, 3aster se bracket append tdec(3) addstat("Pseudo R-squared", `e(r2_p)', "Log-likelihood", `e(ll)')
logit vs_12_update treat, r
outreg using tables/TableS03-wi_ballot_secrecy_recall_logit_table.out, 3aster se bracket append tdec(3) addstat("Pseudo R-squared", `e(r2_p)', "Log-likelihood", `e(ll)')
logit vs_12_update treat `controls', r
outreg using tables/TableS03-wi_ballot_secrecy_recall_logit_table.out, 3aster se bracket append tdec(3) addstat("Pseudo R-squared", `e(r2_p)', "Log-likelihood", `e(ll)')

logit vg_12_update treat if post08reg == 0, r
outreg using tables/TableS04-wi_ballot_secrecy_general_logit_table.out, 3aster se bracket replace tdec(3) addstat("Pseudo R-squared", `e(r2_p)', "Log-likelihood", `e(ll)')
logit vg_12_update treat `controls' if post08reg == 0, r
outreg using tables/TableS04-wi_ballot_secrecy_general_logit_table.out, 3aster se bracket append tdec(3) addstat("Pseudo R-squared", `e(r2_p)', "Log-likelihood", `e(ll)')
logit vg_12_update treat, r
outreg using tables/TableS04-wi_ballot_secrecy_general_logit_table.out, 3aster se bracket append tdec(3) addstat("Pseudo R-squared", `e(r2_p)', "Log-likelihood", `e(ll)')
logit vg_12_update treat `controls', r
outreg using tables/TableS04-wi_ballot_secrecy_general_logit_table.out, 3aster se bracket append tdec(3) addstat("Pseudo R-squared", `e(r2_p)', "Log-likelihood", `e(ll)')

**robustness checks for imbalanced fixed effects
*models without robust standard errors
reg vs_12_update treat if post08reg == 0
outreg using tables/TableXX01-wi_ballot_secrecy_pre08_recall_norobust_table.out, 3aster se bracket replace tdec(3)
xtreg vs_12_update treat if post08reg == 0, fe i(township_id)
outreg using tables/TableXX01-wi_ballot_secrecy_pre08_recall_norobust_table.out, 3aster se bracket append tdec(3) addstat("R-squared Within", `e(r2_w)')
reg vs_12_update treat `controls' if post08reg == 0
outreg using tables/TableXX01-wi_ballot_secrecy_pre08_recall_norobust_table.out, 3aster se bracket append tdec(3)
xtreg vs_12_update treat `controls' if post08reg == 0, fe i(township_id)
outreg using tables/TableXX01-wi_ballot_secrecy_pre08_recall_norobust_table.out, 3aster se bracket append tdec(3) addstat("R-squared Within", `e(r2_w)')

reg vg_12_update treat if post08reg == 0
outreg using tables/TableXX02-wi_ballot_secrecy_pre08_general_norobust_table.out, 3aster se bracket replace tdec(3)
xtreg vg_12_update treat if post08reg == 0, fe i(township_id)
outreg using tables/TableXX02-wi_ballot_secrecy_pre08_general_norobust_table.out, 3aster se bracket append tdec(3) addstat("R-squared Within", `e(r2_w)')
reg vg_12_update treat `controls' if post08reg == 0
outreg using tables/TableXX02-wi_ballot_secrecy_pre08_general_norobust_table.out, 3aster se bracket append tdec(3)
xtreg vg_12_update treat `controls' if post08reg == 0, fe i(township_id)
outreg using tables/TableXX02-wi_ballot_secrecy_pre08_general_norobust_table.out, 3aster se bracket append tdec(3) addstat("R-squared Within", `e(r2_w)')

*models including only fixed effects units that meet a certain threshold
reg vs_12_update treat if post08reg == 0 & numobsFE >= 5, r
outreg using tables/TableXX03-wi_ballot_secrecy_pre08_recall_fe_robust1_table.out, 3aster se bracket replace tdec(3)
xtreg vs_12_update treat if post08reg == 0 & numobsFE >= 5, r fe i(township_id) 
outreg using tables/TableXX03-wi_ballot_secrecy_pre08_recall_fe_robust1_table.out, 3aster se bracket append tdec(3) addstat("R-squared Within", `e(r2_w)')
tab township treat if e(sample), sum(vs_12_update)
reg vs_12_update treat if post08reg == 0 & numobsFE >= 10
outreg using tables/TableXX03-wi_ballot_secrecy_pre08_recall_fe_robust1_table.out, 3aster se bracket append tdec(3)
xtreg vs_12_update treat if post08reg == 0 & numobsFE >= 10, r fe i(township_id)
outreg using tables/TableXX03-wi_ballot_secrecy_pre08_recall_fe_robust1_table.out, 3aster se bracket append tdec(3) addstat("R-squared Within", `e(r2_w)')
tab township treat if e(sample), sum(vs_12_update)
reg vs_12_update treat if post08reg == 0 & numobsFE >= 50
outreg using tables/TableXX03-wi_ballot_secrecy_pre08_recall_fe_robust1_table.out, 3aster se bracket append tdec(3)
xtreg vs_12_update treat if post08reg == 0 & numobsFE >= 50, r fe i(township_id)
outreg using tables/TableXX03-wi_ballot_secrecy_pre08_recall_fe_robust1_table.out, 3aster se bracket append tdec(3) addstat("R-squared Within", `e(r2_w)')
tab township treat if e(sample), sum(vs_12_update)
reg vs_12_update treat if post08reg == 0 & numobsFE >= 100
outreg using tables/TableXX03-wi_ballot_secrecy_pre08_recall_fe_robust1_table.out, 3aster se bracket append tdec(3)
xtreg vs_12_update treat if post08reg == 0 & numobsFE >= 100, r fe i(township_id)
outreg using tables/TableXX03-wi_ballot_secrecy_pre08_recall_fe_robust1_table.out, 3aster se bracket append tdec(3) addstat("R-squared Within", `e(r2_w)')
tab township treat if e(sample), sum(vs_12_update)

reg vs_12_update treat `controls' if post08reg == 0 & numobsFE >= 5, r
outreg using tables/TableXX04-wi_ballot_secrecy_pre08_recall_fe_robust2_table.out, 3aster se bracket replace tdec(3)
xtreg vs_12_update treat `controls' if post08reg == 0 & numobsFE >= 5, r fe i(township_id) 
outreg using tables/TableXX04-wi_ballot_secrecy_pre08_recall_fe_robust2_table.out, 3aster se bracket append tdec(3) addstat("R-squared Within", `e(r2_w)')
reg vs_12_update treat `controls' if post08reg == 0 & numobsFE >= 10
outreg using tables/TableXX04-wi_ballot_secrecy_pre08_recall_fe_robust2_table.out, 3aster se bracket append tdec(3)
xtreg vs_12_update treat `controls' if post08reg == 0 & numobsFE >= 10, r fe i(township_id)
outreg using tables/TableXX04-wi_ballot_secrecy_pre08_recall_fe_robust2_table.out, 3aster se bracket append tdec(3) addstat("R-squared Within", `e(r2_w)')
reg vs_12_update treat `controls' if post08reg == 0 & numobsFE >= 50
outreg using tables/TableXX04-wi_ballot_secrecy_pre08_recall_fe_robust2_table.out, 3aster se bracket append tdec(3)
xtreg vs_12_update treat `controls' if post08reg == 0 & numobsFE >= 50, r fe i(township_id)
outreg using tables/TableXX04-wi_ballot_secrecy_pre08_recall_fe_robust2_table.out, 3aster se bracket append tdec(3) addstat("R-squared Within", `e(r2_w)')
reg vs_12_update treat `controls' if post08reg == 0 & numobsFE >= 100
outreg using tables/TableXX04-wi_ballot_secrecy_pre08_recall_fe_robust2_table.out, 3aster se bracket append tdec(3)
xtreg vs_12_update treat `controls' if post08reg == 0 & numobsFE >= 100, r fe i(township_id)
outreg using tables/TableXX04-wi_ballot_secrecy_pre08_recall_fe_robust2_table.out, 3aster se bracket append tdec(3) addstat("R-squared Within", `e(r2_w)')

reg vg_12_update treat if post08reg == 0 & numobsFE >= 5, r
outreg using tables/TableXX05-wi_ballot_secrecy_pre08_general_fe_robust1_table.out, 3aster se bracket replace tdec(3)
xtreg vg_12_update treat if post08reg == 0 & numobsFE >= 5, r fe i(township_id) 
outreg using tables/TableXX05-wi_ballot_secrecy_pre08_general_fe_robust1_table.out, 3aster se bracket append tdec(3) addstat("R-squared Within", `e(r2_w)')
tab township treat if e(sample), sum(vg_12_update)
reg vg_12_update treat if post08reg == 0 & numobsFE >= 10
outreg using tables/TableXX05-wi_ballot_secrecy_pre08_general_fe_robust1_table.out, 3aster se bracket append tdec(3)
xtreg vg_12_update treat if post08reg == 0 & numobsFE >= 10, r fe i(township_id)
outreg using tables/TableXX05-wi_ballot_secrecy_pre08_general_fe_robust1_table.out, 3aster se bracket append tdec(3) addstat("R-squared Within", `e(r2_w)')
tab township treat if e(sample), sum(vg_12_update)
reg vg_12_update treat if post08reg == 0 & numobsFE >= 50
outreg using tables/TableXX05-wi_ballot_secrecy_pre08_general_fe_robust1_table.out, 3aster se bracket append tdec(3)
xtreg vg_12_update treat if post08reg == 0 & numobsFE >= 50, r fe i(township_id)
outreg using tables/TableXX05-wi_ballot_secrecy_pre08_general_fe_robust1_table.out, 3aster se bracket append tdec(3) addstat("R-squared Within", `e(r2_w)')
tab township treat if e(sample), sum(vg_12_update)
reg vg_12_update treat if post08reg == 0 & numobsFE >= 100
outreg using tables/TableXX05-wi_ballot_secrecy_pre08_general_fe_robust1_table.out, 3aster se bracket append tdec(3)
xtreg vg_12_update treat if post08reg == 0 & numobsFE >= 100, r fe i(township_id)
outreg using tables/TableXX05-wi_ballot_secrecy_pre08_general_fe_robust1_table.out, 3aster se bracket append tdec(3) addstat("R-squared Within", `e(r2_w)')
tab township treat if e(sample), sum(vg_12_update)

reg vg_12_update treat `controls' if post08reg == 0 & numobsFE >= 5, r
outreg using tables/TableXX06-wi_ballot_secrecy_pre08_general_fe_robust2_table.out, 3aster se bracket replace tdec(3)
xtreg vg_12_update treat `controls' if post08reg == 0 & numobsFE >= 5, r fe i(township_id) 
outreg using tables/TableXX06-wi_ballot_secrecy_pre08_general_fe_robust2_table.out, 3aster se bracket append tdec(3) addstat("R-squared Within", `e(r2_w)')
reg vg_12_update treat `controls' if post08reg == 0 & numobsFE >= 10
outreg using tables/TableXX06-wi_ballot_secrecy_pre08_general_fe_robust2_table.out, 3aster se bracket append tdec(3)
xtreg vg_12_update treat `controls' if post08reg == 0 & numobsFE >= 10, r fe i(township_id)
outreg using tables/TableXX06-wi_ballot_secrecy_pre08_general_fe_robust2_table.out, 3aster se bracket append tdec(3) addstat("R-squared Within", `e(r2_w)')
reg vg_12_update treat `controls' if post08reg == 0 & numobsFE >= 50
outreg using tables/TableXX06-wi_ballot_secrecy_pre08_general_fe_robust2_table.out, 3aster se bracket append tdec(3)
xtreg vg_12_update treat `controls' if post08reg == 0 & numobsFE >= 50, r fe i(township_id)
outreg using tables/TableXX06-wi_ballot_secrecy_pre08_general_fe_robust2_table.out, 3aster se bracket append tdec(3) addstat("R-squared Within", `e(r2_w)')
reg vg_12_update treat `controls' if post08reg == 0 & numobsFE >= 100
outreg using tables/TableXX06-wi_ballot_secrecy_pre08_general_fe_robust2_table.out, 3aster se bracket append tdec(3)
xtreg vg_12_update treat `controls' if post08reg == 0 & numobsFE >= 100, r fe i(township_id)
outreg using tables/TableXX06-wi_ballot_secrecy_pre08_general_fe_robust2_table.out, 3aster se bracket append tdec(3) addstat("R-squared Within", `e(r2_w)')

clear

log close
