/* This file merges pre-election assignment to treatment with post-election vote
   information for an experiment on ballot secrecy performed during the 
   2010 Connecticut General Election.*/
 
set more off
clear
log using logs/03_connecticut_secret_ballot_post_merge.txt, text replace

use ../NonPublicReplicationArchive/data/ct/ct_experiment/SecretBallotFieldExperiment_WithVoterIDForPersistencePaper.dta, clear

* Restrict to strata #1 and secret ballot and placebo treatments
keep if s_r_v==1
keep if treatment==1 | treatment==2 | (treatment<=7 & treatment>=5)

drop sex_3 v_cong_general_06 v_pres_general_04 v_pres_general_08 

*2012 turnout
joinby id_voter using ../NonPublicReplicationArchive/data/ct/post-election_turnout/2013_ct_voter_file_reduced.dta, unmatched(master)

*code missing cases as non-turnout
foreach var of varlist v_cong_general_10 v_pres_primary_12 v_cong_primary_12 v_pres_general_12 v_all_11 v_municipal_may11 v_municipal_nov11 {
  replace `var' = 0 if `var' == .
}

*voting index, excluding 2010
gen turnoutindex_post10 = v_pres_primary_12 + v_cong_primary_12 + v_pres_general_12 + v_all_11
gen turnoutindex_12 = v_pres_primary_12 + v_cong_primary_12 + v_pres_general_12
label var turnoutindex_12 "2012 Elections Voted In (0-3)"

*fill in missing ballot percentage by town for non-merged cases
replace percent_missing = 0 if percent_missing < 0 & percent_missing ~= .
egen temp = mode(percent_missing), by(town_id)
replace percent_missing = temp if percent_missing == .

gen anypost10turnout = turnoutindex_post10 > 0 & turnoutindex_post10 ~= .

label var v_cong_general_10 "Voted in 2010 General Election (1 = Yes)"
label var anypost10turnout "Any Turnout Post-2010 (1 = Yes)"
label var v_municipal_may11 "Voted in May 2011 Local Elections (1 = Yes)"
label var v_municipal_nov11 "Voted in Nov. 2011 Local Elections (1 = Yes)"
label var v_pres_primary_12 "Voted in 2012 Pres. Primary (1 = Yes)"
label var v_cong_primary_12 "Voted in 2012 Non-Pres. Primary (1 = Yes)"
label var v_pres_general_12 "Voted in 2012 General Election (1 = Yes)"

gen unreturnedmail = (returnedmail == 0 & badaddress_v2 == 0)
  
*mean deviate and unit change age and age squared
qui sum age
gen age_md = age -`r(mean)'
label variable age_md "Age (Mean-Deviated)"
gen age_sq_md = age_sq / 100
qui sum age_sq_md
replace age_sq_md = age_sq_md - `r(mean)'
label variable age_sq_md "Age-Squared (n Hundreds, Mean-Deviated)"

gen anysecrecytreatment = treatment > 4 & treatment < 8
label variable anysecrecytreatment "Any Secrecy Treatment"
tab treatment anysecrecytreatment

gen sosplacebotreatments = (treatment == 1) | (treatment == 2)
label variable sosplacebotreatments "SOS Placebo Treatments"
tab treatment sosplacebotreatments

rename congress cong_dist
tab cong_dist, gen(cong_dist_)
drop cong_dist_1

label var cong_dist_2 "Congressional District 2"
label var cong_dist_3 "Congressional District 3"
label var cong_dist_4 "Congressional District 4"
label var cong_dist_5 "Congressional District 5"

label var town1_block "Town = Bridgeport"
label var town2_block "Town = New Haven"
label var town3_block "Town = Stamford"
label var town4_block "Town = Hartford"
label var town5_block "Town = Waterbury"
label var town6_block "Town = Norwalk"

label var sex_1 "Female (1 = Yes)"
label var sex_2 "Male (1 = Yes)"

forvalues x = 1/4 {
  label var i_grp_addr_`x' "Number in Household = `x'"
}

*keep variables used in analyses
keep anysecrecytreatment age*md sex_* dem rep i_grp_addr_1 - i_grp_addr_4 town*_block v_cong_general_10 turnoutindex_12 v_pres_primary_12 v_cong_primary_12 v_pres_general_12 badaddress sosplacebotreatments anysecrecytreatment 

compress

*save anonymized dataset for analysis
save ct_ballot_secrecy.dta, replace

log close
clear
