/* This file merges pre-election assignment to treatment with post-election vote
   information for an experiment on group competition performed during the 
   2012 Wisconsin Recall Election.
    - Used for placebo-like test for ballot secrecy experiment.*/

set more off
clear
log using logs/05_wisconsin_group_competition_post_merge.txt, text replace


**MERGE TREATMENT ASSIGNMENT DATA WITH POST-ELECTION TURNOUT DATA
*group competition experiment
use ../NonPublicReplicationArchive/data/wi/ai_dataset/group_competition_list_1.dta, clear
drop e2012*
sort dwid
tostring e2001p e2003g e2006g e2006p e2006s e2007g e2007p e2007s e2008g e2008p e2008s e2009g e2009s e2010g e2010p e2011g, replace
foreach i of varlist e2008s e2009s {
  replace `i' = "" if `i' == "."
}
merge 1:1 dwid using ../NonPublicReplicationArchive/data/wi/post-election_turnout/post_vote_data01.dta, keepusing(e2000g e2000p e2000s e2001g e2001p e2001s e2002g e2002p e2002s e2003g e2003p e2003s e2004g e2004p e2004s e2005g e2005p e2005s e2006g e2006p e2006s e2007g e2007p e2007s e2008g e2008p e2008s e2009g e2009p e2009s e2010g e2010p e2010s e2011g e2011p e2011s e2012p e2012s) gen(postmerge1)
drop if postmerge1 == 2
merge 1:1 dwid using ../NonPublicReplicationArchive/data/wi/post-election_turnout/post_vote_data02.dta, keepusing(e2012g) gen(postmerge2)
drop if postmerge2 == 2

*CLEAN DATA
*generate updated vote history variables
label define vote 0 "No Vote" 1 "Voted", replace

foreach i of varlist e20* {
  qui gen v`=substr("`i'", 6, 1)'_`=substr("`i'", 4, 2)'_update = 0
  qui replace v`=substr("`i'", 6, 1)'_`=substr("`i'", 4, 2)'_update = 1 if `i' != ""
  qui label values v`=substr("`i'", 6, 1)'_`=substr("`i'", 4, 2)'_update vote
}

foreach i of varlist vp*update {
  label var `i' "Voted in 20`=substr("`i'", 4, 2)' Primary Election (Yes = 1)"
}

foreach i of varlist vs*update {
  label var `i' "Voted in 20`=substr("`i'", 4, 2)' Special Election (Yes = 1)"
}

foreach i of varlist vg*update {
  label var `i' "Voted in 20`=substr("`i'", 4, 2)' General Election (Yes = 1)"
}


*recodes
gen regdate = date(registrationdate, "YMD")
format regdate %td
gen dob = date(birthdate, "YMD")
format dob %td
gen date_temp = "2012-06-05"
gen vs_12_edate = date(date_temp, "YMD")
format vs_12_edate %td
drop date_temp
gen yearssincereg = (vs_12_edate - regdate) / 365.25
gen d_miss_yearssincereg = yearssincereg == .
gen post08reg = regdate >= d(31oct2008)
replace post08reg = . if regdate == .
gen d_miss_post08reg = post08reg == .
gen age_corrected = floor((vs_12_edate - dob) / 365.25)
gen d_miss_age = age_corrected == .
replace age_corrected = 0 if age_corrected == .
gen hhinc_corrected = cond(medianhhincome == ., 0, medianhhincome / 1000) /*rescaled for easier interpretation*/
gen d_miss_hhinc = medianhhincome == .
gen female = gender == "female"
gen male = gender == "male"
gen d_miss_gender = gender == "unknown"
gen asian = race == "asian"
gen black = race == "black"
gen white = race == "caucasian"
gen latino = race == "hispanic"
gen mideastern = race == "middleEastern"
gen nativeamer = race == "nativeAmerican"
gen d_miss_race = race == "unknown"
egen township_id = group(township)
egen precinct_id = group(uniqueprecinctcode)
gen milwaukee = township == "CITY OF MILWAUKEE"

*variable labels
label var vs_12_update "Voted in 2012 Recall Election (Yes = 1)"
label var treat "Group Competition Treatment (Yes = 1)"
label var yearssincereg "Years Since Registration Date"
label var post08reg "Registered in 2008 or Later (Yes = 1)"
label var d_miss_post08reg "Reg. in 2008 or Later Missing (Yes = 1)"
label var d_miss_yearssincereg "Years Since Reg. Date Missing (Yes = 1)"
label var age_corrected "Age on Election Day (Years)"
label var d_miss_age "Age Missing (Yes = 1)"
label var hhinc_corrected "Median Household Income (Thousands)"
label var d_miss_hhinc "Median Household Income Missing (Yes = 1)"
label var female "Female (Yes = 1)"
label var male "Male (Yes = 1)"
label var d_miss_gender "Gender Missing (Yes = 1)"
label var asian "Asian (Yes = 1)"
label var black "Black (Yes = 1)"
label var white "White (Yes = 1)"
label var latino "Latino (Yes = 1)"
label var mideastern "Middle Eastern (Yes = 1)"
label var nativeamer "Native American (Yes = 1)"
label var d_miss_race "Race Missing (Yes = 1)"
label var township_id "Townships"
label var milwaukee "Milwaukee Resident (Yes = 1)"

*keep variables used in analyses
keep *_update treat yearssincereg age_corrected d_miss_age female d_miss_gender hhinc_corrected d_miss_hhinc asian black latino mideastern nativeamer d_miss_race township_id post08reg milwaukee

compress

*save anonymized dataset for analysis
save wi_group_competition.dta, replace

log close
clear
