library(foreign)
library(ri)

#setwd(...)

wi.data <- read.dta('wi_ballot_secrecy.dta', convert.factors = FALSE)
wi.pre08reg <- wi.data[wi.data$post08reg == 0, ]
ct.data <- read.dta('ct_ballot_secrecy.dta', convert.factors = FALSE)
ct.sample <- ct.data[ct.data$badaddress == 0 &
  (ct.data$sosplacebotreatments == 1 | ct.data$anysecrecytreatment == 1), ]


#only townships with greater than 50 respondents
town.freq <- table(wi.pre08reg$township_id)

wi50greater <- wi.pre08reg[wi.pre08reg$township_id %in% 
  as.numeric(dimnames(town.freq[town.freq >= 50])[[1]]), ]

y50greater <- wi50greater$vs_12_update
Z50greater <- wi50greater$treat
block50greater <- wi50greater$township_id

set.seed(107493)
perms50greater <- genperms(Z50greater, blockvar = block50greater)
probs50greater <- genprobexact(Z50greater, blockvar = block50greater)
ate50greater <- estate(y50greater, Z50greater, prob = probs50greater)
Ys50greater <- genouts(y50greater, Z50greater, ate = 0)
distout50greater <- gendist(Ys50greater, perms50greater, prob = probs50greater)
pdf(file = 'extra_analysis/sharp_null_wi_fe50.pdf')
  dispdist(distout50greater, ate50greater)
dev.off()
ate50greater


y50greater.general <- wi50greater$vg_12_update

set.seed(531593)
perms50greater <- genperms(Z50greater, blockvar = block50greater)
probs50greater <- genprobexact(Z50greater, blockvar = block50greater)
ate50greater.general <- estate(y50greater.general, Z50greater,
  prob = probs50greater)
Ys50greater <- genouts(y50greater.general, Z50greater, ate = 0)
distout50greater <- gendist(Ys50greater, perms50greater, prob = probs50greater)
pdf(file = 'extra_analysis/sharp_null_wi_fe50_general.pdf')
  dispdist(distout50greater, ate50greater.general)
dev.off()
ate50greater.general


y.ct2010.general <- ct.sample$v_cong_general_10
y.ct2012.all <- ct.sample$turnoutindex_12
y.ct2012.presprim <- ct.sample$v_pres_primary_12
y.ct2012.nonpresprim <- ct.sample$v_cong_primary_12
y.ct2012.general <- ct.sample$v_pres_general_12
Z.ct <- ct.sample$anysecrecytreatment

set.seed(437176)
perms.ct2010.general <- genperms(Z.ct, maxiter = 1000)
probs.ct2010.general <- genprobexact(Z.ct)
ate.ct2010.general <- estate(y.ct2010.general, Z.ct, prob = probs.ct2010.general)
Ys.ct2010.general <- genouts(y.ct2010.general, Z.ct, ate = 0)
distout.ct2010.general <- gendist(Ys.ct2010.general, perms.ct2010.general,
  prob = probs.ct2010.general)
pdf(file = 'extra_analysis/sharp_null_ct2010general.pdf')
  dispdist(distout.ct2010.general, ate.ct2010.general)
dev.off()
ate.ct2010.general


set.seed(896534)
perms.ct2012.all <- genperms(Z.ct)
probs.ct2012.all <- genprobexact(Z.ct)
ate.ct2012.all <- estate(y.ct2012.all, Z.ct, prob = probs.ct2012.all)
Ys.ct2012.all <- genouts(y.ct2012.all, Z.ct, ate = 0)
distout.ct2012.all <- gendist(Ys.ct2012.all, perms.ct2012.all,
  prob = probs.ct2012.all)
pdf(file = 'extra_analysis/sharp_null_ct2012all.pdf')
  dispdist(distout.ct2012.all, ate.ct2012.all)
dev.off()
ate.ct2012.all


set.seed(675213)
perms.ct2012.presprim <- genperms(Z.ct)
probs.ct2012.presprim <- genprobexact(Z.ct)
ate.ct2012.presprim <- estate(y.ct2012.presprim, Z.ct,
  prob = probs.ct2012.presprim)
Ys.ct2012.presprim <- genouts(y.ct2012.presprim, Z.ct, ate = 0)
distout.ct2012.presprim <- gendist(Ys.ct2012.presprim, perms.ct2012.presprim,
  prob = probs.ct2012.presprim)
pdf(file = 'extra_analysis/sharp_null_ct2012presprim.pdf')
  dispdist(distout.ct2012.presprim, ate.ct2012.presprim)
dev.off()
ate.ct2012.presprim


set.seed(796242)
perms.ct2012.nonpresprim <- genperms(Z.ct)
probs.ct2012.nonpresprim <- genprobexact(Z.ct)
ate.ct2012.nonpresprim <- estate(y.ct2012.nonpresprim, Z.ct,
  prob = probs.ct2012.nonpresprim)
Ys.ct2012.nonpresprim <- genouts(y.ct2012.nonpresprim, Z.ct, ate = 0)
distout.ct2012.nonpresprim <- gendist(Ys.ct2012.nonpresprim,
  perms.ct2012.nonpresprim, prob = probs.ct2012.nonpresprim)
pdf(file = 'extra_analysis/sharp_null_ct2012nonpresprim.pdf')
  dispdist(distout.ct2012.nonpresprim, ate.ct2012.nonpresprim)
dev.off()
ate.ct2012.nonpresprim


set.seed(882249)
perms.ct2012.general <- genperms(Z.ct)
probs.ct2012.general <- genprobexact(Z.ct)
ate.ct2012.general <- estate(y.ct2012.general, Z.ct,
  prob = probs.ct2012.general)
Ys.ct2012.general <- genouts(y.ct2012.general, Z.ct, ate = 0)
distout.ct2012.general <- gendist(Ys.ct2012.general, perms.ct2012.general,
  prob = probs.ct2012.general)
pdf(file = 'extra_analysis/sharp_null_ct2012general.pdf')
  dispdist(distout.ct2012.general, ate.ct2012.general)
dev.off()
ate.ct2012.general
